==> org.eclipse.jdt.ui.source_3.7.0.v20101027-1300.jar: org/eclipse/jdt/internal/ui/packageview/PackageExplorerProblemsDecorator.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2010 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.ui.packageview;

import org.eclipse.core.runtime.IAdaptable;

import org.eclipse.ui.IWorkingSet;

import org.eclipse.jdt.ui.JavaElementImageDescriptor;

import org.eclipse.jdt.internal.ui.viewsupport.TreeHierarchyLayoutProblemsDecorator;


public class PackageExplorerProblemsDecorator extends TreeHierarchyLayoutProblemsDecorator {

	public PackageExplorerProblemsDecorator() {
		super();
	}

	public PackageExplorerProblemsDecorator(boolean isFlatLayout) {
		super(isFlatLayout);
	}

	protected int computeAdornmentFlags(Object obj) {
		if (!(obj instanceof IWorkingSet))
			return super.computeAdornmentFlags(obj);

		IWorkingSet workingSet= (IWorkingSet)obj;
		IAdaptable[] elements= workingSet.getElements();
		int result= 0;
		for (int i= 0; i < elements.length; i++) {
			IAdaptable element= elements[i];
			int flags= super.computeAdornmentFlags(element);
			if ((flags & JavaElementImageDescriptor.BUILDPATH_ERROR) != 0)
				return JavaElementImageDescriptor.BUILDPATH_ERROR;
			result|= flags;
		}
		if ((result & JavaElementImageDescriptor.ERROR) != 0)
			return JavaElementImageDescriptor.ERROR;
		else if ((result & JavaElementImageDescriptor.WARNING) != 0)
			return JavaElementImageDescriptor.WARNING;
		return 0;
	}
}

==> org.eclipse.jdt.ui.source_3.13.100.v20180330-0726.jar: org/eclipse/jdt/internal/ui/packageview/PackageExplorerProblemsDecorator.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2016 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.ui.packageview;

import org.eclipse.core.runtime.IAdaptable;

import org.eclipse.ui.IWorkingSet;

import org.eclipse.jdt.ui.JavaElementImageDescriptor;

import org.eclipse.jdt.internal.ui.viewsupport.TreeHierarchyLayoutProblemsDecorator;


public class PackageExplorerProblemsDecorator extends TreeHierarchyLayoutProblemsDecorator {

	public PackageExplorerProblemsDecorator() {
		super();
	}

	public PackageExplorerProblemsDecorator(boolean isFlatLayout) {
		super(isFlatLayout);
	}

	@Override
	protected int computeAdornmentFlags(Object obj) {
		if (!(obj instanceof IWorkingSet))
			return super.computeAdornmentFlags(obj);

		IWorkingSet workingSet= (IWorkingSet)obj;
		IAdaptable[] elements= workingSet.getElements();
		int result= 0;
		for (int i= 0; i < elements.length; i++) {
			IAdaptable element= elements[i];
			int flags= super.computeAdornmentFlags(element);
			if ((flags & JavaElementImageDescriptor.BUILDPATH_ERROR) != 0)
				return JavaElementImageDescriptor.BUILDPATH_ERROR;
			result|= flags;
		}
		if ((result & JavaElementImageDescriptor.ERROR) != 0)
			return JavaElementImageDescriptor.ERROR;
		else if ((result & JavaElementImageDescriptor.WARNING) != 0)
			return JavaElementImageDescriptor.WARNING;
		else if ((result & JavaElementImageDescriptor.INFO) != 0)
			return JavaElementImageDescriptor.INFO;
		return 0;
	}
}
